import { Exception } from "./Exception";
interface Log {
    date: Date;
    result: "OK" | "WARN" | "ERROR";
    elapsedTime: number;
    context: {
        [key: string]: string;
    };
    info: {
        [key: string]: string;
    };
    action?: string;
    errorCode?: string;
    errorMessage?: string;
}
interface ErrorLogEntry {
    elapsedTime: number;
    action: string;
    errorCode: string;
    errorMessage: string;
    info: {
        [key: string]: string;
    };
}
/**
 * If eventLogger config is provided in non-DEV environment
 * All collected logs will automatically sent to {serverURL} every {sendingFrequency} second
 *
 * The request will be PUT to the server in the following format
 *      {events: Log[]}
 */
export interface LoggerConfig {
    serverURL: string;
    sendingFrequency: number;
    maskedKeywords?: RegExp[];
}
export interface Logger {
    addContext(context: {
        [key: string]: string | (() => string);
    }): void;
    /**
     * Add a log item, whose result is OK
     */
    info(action: string, info: {
        [key: string]: string;
    }, elapsedTime?: number): void;
    /**
     * Add a log item, whose result is WARN
     * @errorCode: Naming in upper-case and underscore, e.g: SOME_DATA
     */
    warn(data: ErrorLogEntry): void;
    /**
     * Add a log item, whose result is ERROR
     * @errorCode: Naming in upper-case and underscore, e.g: SOME_DATA
     */
    error(data: ErrorLogEntry): void;
}
export declare class LoggerImpl implements Logger {
    private environmentContext;
    private logQueue;
    constructor();
    addContext(context: {
        [key: string]: string | (() => string);
    }): void;
    info(action: string, info: {
        [key: string]: string;
    }, elapsedTime?: number): void;
    warn(data: ErrorLogEntry): void;
    error(data: ErrorLogEntry): void;
    exception(exception: Exception, action?: string, extraInfo?: {
        [key: string]: string;
    }): void;
    collect(): Log[];
    empty(): void;
    private appendLog;
}
export {};
