import { app } from "../app";
import { stringifyWithMask } from "../util/json-util";
/**
 * For latest decorator spec, please ref following:
 *      https://tc39.github.io/proposal-decorators/#sec-decorator-functions-element-descriptor
 *      https://github.com/tc39/proposal-decorators/blob/master/METAPROGRAMMING.md
 */
export { Interval } from "./Interval";
export { Lifecycle } from "./Lifecycle";
export { Loading } from "./Loading";
export { Log } from "./Log";
export { Mutex } from "./Mutex";
export { RetryOnNetworkConnectionError } from "./RetryOnNetworkConnectionError";
export { SilentOnNetworkConnectionError } from "./SilentOnNetworkConnectionError";
export { TimeLimit } from "./TimeLimit";
/**
 * A helper for ActionHandler functions (Saga).
 */
export function createActionHandlerDecorator(interceptor) {
    return (target) => {
        const descriptor = target.descriptor;
        const fn = descriptor.value;
        descriptor.value = function* (...args) {
            const boundFn = fn.bind(this, ...args);
            // Do not use fn.actionName, it returns undefined
            // The reason is, fn is created before module register(), and the actionName had not been attached then
            boundFn.actionName = descriptor.value.actionName;
            boundFn.maskedParams = stringifyWithMask(app.loggerConfig && app.loggerConfig.maskedKeywords ? app.loggerConfig.maskedKeywords : [], "***", ...args) || "[No Parameter]";
            yield* interceptor(boundFn, this);
        };
        return target;
    };
}
/**
 * A helper for regular functions.
 */
export function createRegularDecorator(interceptor) {
    return (target) => {
        const descriptor = target.descriptor;
        const fn = descriptor.value;
        descriptor.value = function (...args) {
            const rootState = app.store.getState();
            const logger = app.logger;
            interceptor(fn.bind(this, ...args), rootState, logger);
        };
        return target;
    };
}
//# sourceMappingURL=index.js.map